==> fpdi_print-1.0.0.tar.gz: fpdi_print/src/Plugin/views/area/FpdiPrintViewsLink.php <==
<?php

namespace Drupal\fpdi_print\Plugin\views\area;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\fpdi_print\Plugin\ExportTypeManagerInterface;
use Drupal\views\Plugin\views\area\TokenizeAreaPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Views area handler for a pdf button.
 *
 * @ingroup views_area_handlers
 *
 * @ViewsArea("fpdi_print_views_link")
 */
class FpdiPrintViewsLink extends TokenizeAreaPluginBase {

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['position_text'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Position configuration'),
      '#description' => t('YAML array format, for example:').'<br/>'."
      <pre>- x: 10
  y: 10
  text: \"[site:name]\"
- x: 20
  y: 10
  text: \"{{ field_name }}\"</pre>
      ",
      '#default_value' => $this->options['position_text'],
    ];
    $form['link_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link text'),
      '#required' => TRUE,
      '#default_value' => $this->options['link_text'],
    ];

    $form['file_pdf'] = [
      '#type' => 'textfield',
      '#title' => $this->t('PDF document (version 1.4) template path'),
      '#description' => t('It doesn\'t work with version 1.5. <br/>System path:'). \Drupal::service('file_system')->realpath(\Drupal::config('system.file')->get('default_scheme') . "://"),
      '#default_value' => $this->options['file_pdf'],
    ];

    $displays = $this->view->displayHandlers->getConfiguration();
    $display_options = [];
    foreach ($displays as $display_id => $display_info) {
      $display_options[$display_id] = $display_info['display_title'];
    }
    $form['display_id'] = [
      '#type' => 'select',
      '#title' => $this->t('View Display'),
      '#options' => $display_options,
      "#empty_option" => t('- Select -'),
      '#default_value' => $this->options['display_id'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render($empty = FALSE) {
    $route_params = [
      'view_name' => $this->view->storage->id(),
      'display_id' => $this->options['display_id'],
      'option_id' => $this->areaType . '-' . $this->options['id'],
    ];
    $link = [
      '#type' => 'link',
      '#title' => $this->options['link_text'],
      '#url' => Url::fromRoute('fpdi_print.view', $route_params, [
        'query' => $this->view->getExposedInput() + ['view_args' => $this->view->args],
      ]),
    ];
    return $link;
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['position_text'] = ['default' => ''];
    $options['file_pdf'] = ['default' => ''];
    $options['link_text'] = ['default' => 'Download PDF'];
    $options['display_id'] = ['default' => $this->view->current_display];
    return $options;
  }

}

==> fpdi_print-1.0.1.tar.gz: fpdi_print/src/Plugin/views/area/FpdiPrintViewsLink.php <==
<?php

namespace Drupal\fpdi_print\Plugin\views\area;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\fpdi_print\Plugin\ExportTypeManagerInterface;
use Drupal\views\Plugin\views\area\TokenizeAreaPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Views area handler for a pdf button.
 *
 * @ingroup views_area_handlers
 *
 * @ViewsArea("fpdi_print_views_link")
 */
class FpdiPrintViewsLink extends TokenizeAreaPluginBase {

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['position_text'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Position configuration'),
      '#description' => t('YAML array format, for example:').'<br/>'."
      <pre>- x: 10
  y: 10
  text: \"[site:name]\"
- x: 20
  y: 10
  text: \"{{ field_name }}\"</pre>
      ",
      '#default_value' => $this->options['position_text'],
    ];
    $form['link_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Link text'),
      '#required' => TRUE,
      '#default_value' => $this->options['link_text'],
    ];

    $form['file_pdf'] = [
      '#type' => 'textfield',
      '#title' => $this->t('PDF document (version 1.4) template path'),
      '#description' => t('It does not work with version 1.5 later, convert to acrobat 5. <br/>Your system path: '). \Drupal::service('file_system')->realpath(\Drupal::config('system.file')->get('default_scheme') . "://"),
      '#default_value' => $this->options['file_pdf'],
    ];

    $form['file_pdf_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Save PDF to name'),
      '#description' => t('Leave blank if you view the pdf with the browser, set the file name, it will download the pdf, set the path + the file name, it will save in the path and download. <br/> Token can be used for filename'),
      '#default_value' => $this->options['file_pdf_name'],
    ];

    $displays = $this->view->displayHandlers->getConfiguration();
    $display_options = [];
    foreach ($displays as $display_id => $display_info) {
      $display_options[$display_id] = $display_info['display_title'];
    }
    $form['display_id'] = [
      '#type' => 'select',
      '#title' => $this->t('View Display'),
      '#options' => $display_options,
      "#empty_option" => t('- Select -'),
      '#default_value' => $this->options['display_id'],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render($empty = FALSE) {
    $route_params = [
      'view_name' => $this->view->storage->id(),
      'display_id' => $this->options['display_id'],
      'option_id' => $this->areaType . '-' . $this->options['id'],
    ];
    $link = [
      '#type' => 'link',
      '#title' => $this->options['link_text'],
      '#url' => Url::fromRoute('fpdi_print.view', $route_params, [
        'query' => $this->view->getExposedInput() + ['view_args' => $this->view->args],
      ]),
    ];
    return $link;
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['position_text'] = ['default' => ''];
    $options['file_pdf'] = ['default' => ''];
    $options['file_pdf_name'] = ['default' => ''];
    $options['link_text'] = ['default' => t('Download PDF')];
    $options['display_id'] = ['default' => $this->view->current_display];
    return $options;
  }

}
